@@ -10,22 +10,15 @@
 # Modules and declarations
 ##############################################################################
 
-package Pod::Text::Termcap;
+package Pod::Text::Termcap v6.0.2;
 
-use 5.006;
-use strict;
+use 5.012;
+use parent qw(Pod::Text);
 use warnings;
 
-use Pod::Text ();
 use POSIX ();
 use Term::Cap;
 
-use vars qw(@ISA $VERSION);
-
-@ISA = qw(Pod::Text);
-
-$VERSION = '4.12';
-
 ##############################################################################
 # Overrides
 ##############################################################################
@@ -36,14 +29,6 @@ sub new {
     my ($self, %args) = @_;
     my ($ospeed, $term, $termios);
 
-    # $ENV{HOME} is usually not set on Windows.  The default Term::Cap path
-    # may not work on Solaris.
-    unless (exists $ENV{TERMPATH}) {
-        my $home = exists $ENV{HOME} ? "$ENV{HOME}/.termcap:" : '';
-        $ENV{TERMPATH} =
-          "${home}/etc/termcap:/usr/share/misc/termcap:/usr/share/lib/termcap";
-    }
-
     # Fall back on a hard-coded terminal speed if POSIX::Termios isn't
     # available (such as on VMS).
     eval { $termios = POSIX::Termios->new };
@@ -80,10 +65,12 @@ sub new {
     # Initialize Pod::Text.
     $self = $self->SUPER::new (%args);
 
-    # Fall back on the ANSI escape sequences if Term::Cap doesn't work.
-    $$self{BOLD} = $bold || "\e[1m";
-    $$self{UNDL} = $undl || "\e[4m";
-    $$self{NORM} = $norm || "\e[m";
+    # If we were unable to get any of the formatting sequences, don't attempt
+    # that type of formatting.  This will do weird things if bold or underline
+    # were available but normal wasn't, but hopefully that will never happen.
+    $$self{BOLD} = $bold || q{};
+    $$self{UNDL} = $undl || q{};
+    $$self{NORM} = $norm || q{};
 
     return $self;
 }
@@ -106,11 +93,19 @@ sub cmd_head2 {
 sub cmd_b { my $self = shift; return "$$self{BOLD}$_[1]$$self{NORM}" }
 sub cmd_i { my $self = shift; return "$$self{UNDL}$_[1]$$self{NORM}" }
 
+# Return a regex that matches a formatting sequence.  This will only be valid
+# if we were able to get at least some termcap information.
+sub format_regex {
+    my ($self) = @_;
+    my @codes = ($self->{BOLD}, $self->{UNDL}, $self->{NORM});
+    return join(q{|}, map { $_ eq q{} ? () : "\Q$_\E" } @codes);
+}
+
 # Analyze a single line and return any formatting codes in effect at the end
 # of that line.
 sub end_format {
     my ($self, $line) = @_;
-    my $pattern = "(\Q$$self{BOLD}\E|\Q$$self{UNDL}\E|\Q$$self{NORM}\E)";
+    my $pattern = "(" . $self->format_regex() . ")";
     my $current;
     while ($line =~ /$pattern/g) {
         my $code = $1;
@@ -147,17 +142,19 @@ sub wrap {
     my $spaces = ' ' x $$self{MARGIN};
     my $width = $$self{opt_width} - $$self{MARGIN};
 
+    # If we were unable to find any termcap sequences, use Pod::Text wrapping.
+    if ($self->{BOLD} eq q{} && $self->{UNDL} eq q{} && $self->{NORM} eq q{}) {
+        return $self->SUPER::wrap($_);
+    }
+
     # $code matches a single special sequence.  $char matches any number of
     # special sequences preceding a single character other than a newline.
     # $shortchar matches some sequence of $char ending in codes followed by
     # whitespace or the end of the string.  $longchar matches exactly $width
     # $chars, used when we have to truncate and hard wrap.
-    #
-    # $shortchar and $longchar are created in a slightly odd way because the
-    # construct ${char}{0,$width} didn't do the right thing until Perl 5.8.x.
-    my $code = "(?:\Q$$self{BOLD}\E|\Q$$self{UNDL}\E|\Q$$self{NORM}\E)";
+    my $code = "(?:" . $self->format_regex() . ")";
     my $char = "(?>$code*[^\\n])";
-    my $shortchar = '^(' . $char . "{0,$width}(?>$code*)" . ')(?:\s+|\z)';
+    my $shortchar = '^(' . $char . "{0,$width}(?>$code*)" . ')(?:[ \t\n]+|\z)';
     my $longchar = '^(' . $char . "{$width})";
     while (length > $width) {
         if (s/$shortchar// || s/$longchar//) {
@@ -200,13 +197,13 @@ sub wrap {
 1;
 __END__
 
+=for stopwords
+ECMA-48 VT100 Allbery Solaris TERMPATH unformatted
+
 =head1 NAME
 
 Pod::Text::Termcap - Convert POD data to ASCII text with format escapes
 
-=for stopwords
-ECMA-48 VT100 Allbery Solaris TERMPATH
-
 =head1 SYNOPSIS
 
     use Pod::Text::Termcap;
@@ -225,34 +222,48 @@ text using the correct termcap escape sequences for the current terminal.
 Apart from the format codes, it in all ways functions like Pod::Text.  See
 L<Pod::Text> for details and available options.
 
-=head1 ENVIRONMENT
+This module uses L<Term::Cap> to find the correct terminal settings.  See the
+documentation of that module for how it finds terminal database information
+and how to override that behavior if necessary.  If unable to find control
+strings for bold and underscore formatting, that formatting is skipped,
+resulting in the same output as Pod::Text.
 
-This module sets the TERMPATH environment variable globally to:
+=head1 COMPATIBILITY
 
-    $HOME/.termcap:/etc/termcap:/usr/share/misc/termcap:/usr/share/lib/termcap
+Pod::Text::Termcap 0.04 (based on L<Pod::Parser>) was the first version of
+this module included with Perl, in Perl 5.6.0.
 
-if it isn't already set.  (The first entry is omitted if the HOME
-environment variable isn't set.)  This is a (very old) workaround for
-problems finding termcap information on older versions of Solaris, and is
-not good module behavior.  Please do not rely on this behavior; it may be
-dropped in a future release.
+The current API based on L<Pod::Simple> was added in Pod::Text::Termcap 2.00.
+Pod::Text::Termcap 2.01 was included in Perl 5.9.3, the first version of Perl
+to incorporate those changes.
 
-=head1 NOTES
+Pod::Text::Termcap 4.13 stopped setting the TERMPATH environment variable
+during module load.  It also stopped falling back on VT100 escape sequences if
+Term::Cap was not able to find usable escape sequences, instead producing
+unformatted output for better results on dumb terminals.  The next version to
+be incorporated into Perl, 4.14, was included in Perl 5.31.8.
 
-This module uses Term::Cap to retrieve the formatting escape sequences for
-the current terminal, and falls back on the ECMA-48 (the same in this
-regard as ANSI X3.64 and ISO 6429, the escape codes also used by DEC VT100
-terminals) if the bold, underline, and reset codes aren't set in the
-termcap information.
+Several problems with wrapping and line length were fixed as recently as
+Pod::Text::Termcap 6.0.0.
+
+This module inherits its API and most behavior from Pod::Text, so the details
+in L<Pod::Text/COMPATIBILITY> also apply.  Pod::Text and Pod::Text::Termcap
+have had the same module version since 4.00, included in Perl 5.23.7.  (They
+unfortunately diverge in confusing ways prior to that.)
+
+=head1 CAVEATS
+
+Line wrapping is done only at ASCII spaces and tabs, rather than using a
+correct Unicode-aware line wrapping algorithm.
 
 =head1 AUTHOR
 
-Russ Allbery <rra@cpan.org>.
+Russ Allbery <rra@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 1999, 2001-2002, 2004, 2006, 2008-2009, 2014-2015, 2018 Russ Allbery
-<rra@cpan.org>
+Copyright 1999, 2001-2002, 2004, 2006, 2008-2009, 2014-2015, 2018-2019, 2022,
+2024 Russ Allbery <rra@cpan.org>
 
 This program is free software; you may redistribute it and/or modify it
 under the same terms as Perl itself.
