@@ -784,8 +784,8 @@ PERLVARI(I, collation_standard, bool, TRUE)
 PERLVAR(I, in_utf8_COLLATE_locale, bool)
 #endif /* USE_LOCALE_COLLATE */
 
-PERLVARI(I, langinfo_buf, char *, NULL)
-PERLVARI(I, langinfo_bufsize, Size_t, 0)
+PERLVARI(I, langinfo_sv, SV *, NULL)         /* For Perl_langinfo8? */
+PERLVARI(I, scratch_langinfo, SV *, NULL)     /* For internal use */
 PERLVARI(I, setlocale_buf, char *, NULL)
 PERLVARI(I, setlocale_bufsize, Size_t, 0)
 
@@ -793,13 +793,6 @@ PERLVARI(I, setlocale_bufsize, Size_t, 0)
 PERLVARI(I, less_dicey_locale_buf, char *, NULL)
 PERLVARI(I, less_dicey_locale_bufsize, Size_t, 0)
 #endif
-#if ! defined(HAS_NL_LANGINFO)          \
- &&   defined(USE_LOCALE_CTYPE)         \
- && ! defined(WIN32)                    \
- && ! defined(HAS_MBTOWC)               \
- && ! defined(HAS_MBRTOWC)
-PERLVARI(I, langinfo_recursed, unsigned int, 0)
-#endif
 
 #ifdef PERL_SAWAMPERSAND
 PERLVAR(I, sawampersand, U8)		/* must save all match strings */
@@ -909,6 +902,7 @@ PERLVAR(I, regex_padav,   AV *)		/* All regex objects, indexed via the
 PERLVAR(I, stashpad,    HV **)		/* for CopSTASH */
 PERLVARI(I, stashpadmax, PADOFFSET, 64)
 PERLVARI(I, stashpadix, PADOFFSET, 0)
+PERLVARI(I, env_mutex_depth, int, 0)     /* Emulate general semaphore */
 #endif
 
 #ifdef USE_REENTRANT_API
@@ -974,8 +968,6 @@ PERLVAR(I, blockhooks,	AV *)
 
 PERLVAR(I, custom_ops,	HV *)		/* custom op registrations */
 
-PERLVAR(I, Xpv,		XPV *)		/* (unused) held temporary value */
-
 /* name of the scopes we've ENTERed. Only used with -DDEBUGGING, but needs to be
    present always, as -DDEBUGGING must be binary compatible with non.  */
 PERLVARI(I, scopestack_name, const char **, NULL)
