@@ -1,13 +1,11 @@
-package builtin 0.011;
+package builtin 0.015;
 
-use strict;
-use warnings;
+use v5.40;
 
-# All code, including &import and &unimport, is implemented by always-present
+# All code, including &import, is implemented by always-present
 # functions in the perl interpreter itself.
 # See also `builtin.c` in perl source
 
-1;
 __END__
 
 =head1 NAME
@@ -18,6 +16,7 @@ builtin - Perl pragma to import built-in utility functions
 
     use builtin qw(
         true false is_bool
+        inf nan
         weaken unweaken is_weak
         blessed refaddr reftype
         created_as_string created_as_number
@@ -27,6 +26,7 @@ builtin - Perl pragma to import built-in utility functions
         trim
         is_tainted
         export_lexically
+        load_module
     );
 
     use builtin ':5.40';  # most of the above
@@ -79,13 +79,15 @@ don't accidentally appear as object methods from a class.
     # Can't locate object method "true" via package "An::Object::Class"
     #   at ...
 
-Imported symbols can also be removed again by using the C<no> keyword:
+Once imported, a lexical function is much like any other lexical symbol
+(such as a variable) in that it cannot be removed again.  If you wish to
+limit the visiblity of an imported C<builtin> function, put it inside its
+own scope:
 
-    use builtin 'true';
-    my $yes = true;
-
-    no builtin 'true';
-    # true() is no longer aliased from builtin
+    {
+      use builtin 'refaddr';
+      ...
+    }
 
 =head2 Version Bundles
 
@@ -117,6 +119,10 @@ distinguished boolean value.
 
 This gives an equivalent value to expressions like C<!!1> or C<!0>.
 
+Available starting with Perl 5.36. Since Perl 5.40, it is no longer
+experimental and it is included in the 5.40 and higher builtin version
+bundles.
+
 =head2 false
 
     $val = false;
@@ -127,6 +133,10 @@ it to be a distinguished boolean value.
 
 This gives an equivalent value to expressions like C<!!0> or C<!1>.
 
+Available starting with Perl 5.36. Since Perl 5.40, it is no longer
+experimental and it is included in the 5.40 and higher builtin version
+bundles.
+
 =head2 is_bool
 
     $bool = is_bool($val);
@@ -142,6 +152,28 @@ or any variable containing one of these results.
 This function used to be named C<isbool>. A compatibility alias is provided
 currently but will be removed in a later version.
 
+Available starting with Perl 5.36.
+
+=head2 inf
+
+    $num = inf;
+
+This function is currently B<experimental>.
+
+Returns the floating-point infinity value.
+
+Available starting with Perl 5.40.
+
+=head2 nan
+
+    $num = nan;
+
+This function is currently B<experimental>.
+
+Returns the floating-point "Not-a-Number" value.
+
+Available starting with Perl 5.40.
+
 =head2 weaken
 
     weaken($ref);
@@ -151,12 +183,20 @@ count of its referent. If only weakened references to a referent remain, it
 will be disposed of, and all remaining weak references to it will have their
 value set to C<undef>.
 
+Available starting with Perl 5.36. Since Perl 5.40, it is no longer
+experimental and it is included in the 5.40 and higher builtin version
+bundles.
+
 =head2 unweaken
 
     unweaken($ref);
 
 Strengthens a reference, undoing the effects of a previous call to L</weaken>.
 
+Available starting with Perl 5.36. Since Perl 5.40, it is no longer
+experimental and it is included in the 5.40 and higher builtin version
+bundles.
+
 =head2 is_weak
 
     $bool = is_weak($ref);
@@ -167,6 +207,10 @@ not weak.
 This function used to be named C<isweak>. A compatibility alias is provided
 currently but will be removed in a later version.
 
+Available starting with Perl 5.36. Since Perl 5.40, it is no longer
+experimental and it is included in the 5.40 and higher builtin version
+bundles.
+
 =head2 blessed
 
     $str = blessed($ref);
@@ -174,6 +218,10 @@ currently but will be removed in a later version.
 Returns the package name for an object reference, or C<undef> for a
 non-reference or reference that is not an object.
 
+Available starting with Perl 5.36. Since Perl 5.40, it is no longer
+experimental and it is included in the 5.40 and higher builtin version
+bundles.
+
 =head2 refaddr
 
     $num = refaddr($ref);
@@ -182,6 +230,10 @@ Returns the memory address for a reference, or C<undef> for a non-reference.
 This value is not likely to be very useful for pure Perl code, but is handy as
 a means to test for referential identity or uniqueness.
 
+Available starting with Perl 5.36. Since Perl 5.40, it is no longer
+experimental and it is included in the 5.40 and higher builtin version
+bundles.
+
 =head2 reftype
 
     $str = reftype($ref);
@@ -190,6 +242,10 @@ Returns the basic container type of the referent of a reference, or C<undef>
 for a non-reference. This is returned as a string in all-capitals, such as
 C<ARRAY> for array references, or C<HASH> for hash references.
 
+Available starting with Perl 5.36. Since Perl 5.40, it is no longer
+experimental and it is included in the 5.40 and higher builtin version
+bundles.
+
 =head2 created_as_string
 
     $bool = created_as_string($val);
@@ -213,6 +269,8 @@ strings. For example
 
     if( created_as_string $val ) { ... }    # this will not execute
 
+Available starting with Perl 5.36.
+
 =head2 created_as_number
 
     $bool = created_as_number($val);
@@ -242,10 +300,14 @@ serialisation modules such as JSON encoders or similar situations, where
 language interoperability concerns require making a distinction between values
 that are fundamentally stringlike versus numberlike in nature.
 
+Available starting with Perl 5.36.
+
 =head2 stringify
 
     $str = stringify($val);
 
+This function is currently B<experimental>.
+
 Returns a new plain perl string that represents the given argument.
 
 When given a value that is already a string, a copy of this value is returned
@@ -262,6 +324,8 @@ overload will return a string that names the underlying container type of
 the reference, its memory address, and possibly its class name if it is an
 object.
 
+Available starting with Perl 5.40.
+
 =head2 ceil
 
     $num = ceil($num);
@@ -269,6 +333,10 @@ object.
 Returns the smallest integer value greater than or equal to the given
 numerical argument.
 
+Available starting with Perl 5.36. Since Perl 5.40, it is no longer
+experimental and it is included in the 5.40 and higher builtin version
+bundles.
+
 =head2 floor
 
     $num = floor($num);
@@ -276,6 +344,10 @@ numerical argument.
 Returns the largest integer value less than or equal to the given numerical
 argument.
 
+Available starting with Perl 5.36. Since Perl 5.40, it is no longer
+experimental and it is included in the 5.40 and higher builtin version
+bundles.
+
 =head2 indexed
 
     @ivpairs = indexed(@items)
@@ -304,6 +376,10 @@ C<foreach> loop syntax; as
 In scalar context this function returns the size of the list that it would
 otherwise have returned, and provokes a warning in the C<scalar> category.
 
+Available starting with Perl 5.36. Since Perl 5.40, it is no longer
+experimental and it is included in the 5.40 and higher builtin version
+bundles.
+
 =head2 trim
 
     $stripped = trim($string);
@@ -331,7 +407,11 @@ C<trim> is equivalent to:
 
     $str =~ s/\A\s+|\s+\z//urg;
 
-For Perl versions where this feature is not available look at the
+Available starting with Perl 5.36. Since Perl 5.40, it is no longer
+experimental and it is included in the 5.40 and higher builtin version
+bundles.
+
+For Perl versions where this function is not available look at the
 L<String::Util> module for a comparable implementation.
 
 =head2 is_tainted
@@ -340,6 +420,8 @@ L<String::Util> module for a comparable implementation.
 
 Returns true when given a tainted variable.
 
+Available starting with Perl 5.38.
+
 =head2 export_lexically
 
     export_lexically($name1, $ref1, $name2, $ref2, ...)
@@ -371,6 +453,29 @@ This must be called at compile time; which typically means during a C<BEGIN>
 block. Usually this would be used as part of an C<import> method of a module,
 when invoked as part of a C<use ...> statement.
 
+Available starting with Perl 5.38.
+
+=head2 load_module
+
+    load_module($module_name);
+
+This function is currently B<experimental>.
+
+Loads a named module from the inclusion paths (C<@INC>).  C<$module_name> must
+be a string that provides a module name.  It cannot be omitted, and providing
+an invalid module name will result in an exception.  Not providing any argument
+results in a compilation error.  Returns the loaded module's name on success.
+
+The effect of C<load_module>-ing a module is mostly the same as C<require>-ing,
+down to the same error conditions when the module does not exist, does not
+compile, or does not evaluate to a true value.  See also
+L<the C<module_true> feature|feature/"The 'module_true' feature">.
+
+C<load_module> can't be used to require a particular version of Perl, nor can
+it be given a bareword module name as an argument.
+
+Available starting with Perl 5.40.
+
 =head1 SEE ALSO
 
 L<perlop>, L<perlfunc>, L<Scalar::Util>
