@@ -6,7 +6,7 @@
  *	This symbol, if defined, indicates that the ioctl() routine is
  *	available to set I/O characteristics
  */
-#define	HAS_IOCTL		/**/
+#define HAS_IOCTL               /**/
  
 /* HAS_UTIME:
  *	This symbol, if defined, indicates that the routine utime() is
@@ -192,7 +192,8 @@ extern int rc;
 #  define pthread_setspecific(k,v)	(*(k)=(v),0)
 #  define pthread_key_create(keyp,flag)			\
         ( DosAllocThreadLocalMemory(1,(unsigned long**)keyp)	\
-          ? Perl_croak_nocontext("Out of memory!"), 1        \
+          /* diag_listed_as: Out of memory in perl:%s */ \
+          ? Perl_croak_nocontext("Out of memory in perl:os2:pthread_key_create"), 1        \
           : 0						\
         )
 #endif /* USE_SLOW_THREAD_SPECIFIC */
@@ -822,50 +823,50 @@ int os2_do_aspawn(pTHX_ SV *really, SV **vmark, SV **vsp);
 #ifndef LOG_DAEMON
 
 /* Replacement for syslog.h */
-#  define	LOG_EMERG	0	/* system is unusable */
-#  define	LOG_ALERT	1	/* action must be taken immediately */
-#  define	LOG_CRIT	2	/* critical conditions */
-#  define	LOG_ERR	3	/* error conditions */
-#  define	LOG_WARNING	4	/* warning conditions */
-#  define	LOG_NOTICE	5	/* normal but significant condition */
-#  define	LOG_INFO	6	/* informational */
-#  define	LOG_DEBUG	7	/* debug-level messages */
+#  define LOG_EMERG     0       /* system is unusable */
+#  define LOG_ALERT     1       /* action must be taken immediately */
+#  define LOG_CRIT      2       /* critical conditions */
+#  define LOG_ERR       3       /* error conditions */
+#  define LOG_WARNING   4       /* warning conditions */
+#  define LOG_NOTICE    5       /* normal but significant condition */
+#  define LOG_INFO      6       /* informational */
+#  define LOG_DEBUG     7       /* debug-level messages */
 
-#  define	LOG_PRIMASK	0x007	/* mask to extract priority part (internal) */
+#  define LOG_PRIMASK   0x007   /* mask to extract priority part (internal) */
                                 /* extract priority */
-#  define	LOG_PRI(p)	((p) & LOG_PRIMASK)
-#  define	LOG_MAKEPRI(fac, pri)	(((fac) << 3) | (pri))
+#  define LOG_PRI(p)    ((p) & LOG_PRIMASK)
+#  define LOG_MAKEPRI(fac, pri) (((fac) << 3) | (pri))
 
 /* facility codes */
-#  define	LOG_KERN	(0<<3)	/* kernel messages */
-#  define	LOG_USER	(1<<3)	/* random user-level messages */
-#  define	LOG_MAIL	(2<<3)	/* mail system */
-#  define	LOG_DAEMON	(3<<3)	/* system daemons */
-#  define	LOG_AUTH	(4<<3)	/* security/authorization messages */
-#  define	LOG_SYSLOG	(5<<3)	/* messages generated internally by syslogd */
-#  define	LOG_LPR	(6<<3)	/* line printer subsystem */
-#  define	LOG_NEWS	(7<<3)	/* network news subsystem */
-#  define	LOG_UUCP	(8<<3)	/* UUCP subsystem */
-#  define	LOG_CRON	(15<<3)	/* clock daemon */
+#  define LOG_KERN      (0<<3)  /* kernel messages */
+#  define LOG_USER      (1<<3)  /* random user-level messages */
+#  define LOG_MAIL      (2<<3)  /* mail system */
+#  define LOG_DAEMON    (3<<3)  /* system daemons */
+#  define LOG_AUTH      (4<<3)  /* security/authorization messages */
+#  define LOG_SYSLOG    (5<<3)  /* messages generated internally by syslogd */
+#  define LOG_LPR       (6<<3)  /* line printer subsystem */
+#  define LOG_NEWS      (7<<3)  /* network news subsystem */
+#  define LOG_UUCP      (8<<3)  /* UUCP subsystem */
+#  define LOG_CRON      (15<<3) /* clock daemon */
         /* other codes through 15 reserved for system use */
-#  define	LOG_LOCAL0	(16<<3)	/* reserved for local use */
-#  define	LOG_LOCAL1	(17<<3)	/* reserved for local use */
-#  define	LOG_LOCAL2	(18<<3)	/* reserved for local use */
-#  define	LOG_LOCAL3	(19<<3)	/* reserved for local use */
-#  define	LOG_LOCAL4	(20<<3)	/* reserved for local use */
-#  define	LOG_LOCAL5	(21<<3)	/* reserved for local use */
-#  define	LOG_LOCAL6	(22<<3)	/* reserved for local use */
-#  define	LOG_LOCAL7	(23<<3)	/* reserved for local use */
+#  define LOG_LOCAL0    (16<<3) /* reserved for local use */
+#  define LOG_LOCAL1    (17<<3) /* reserved for local use */
+#  define LOG_LOCAL2    (18<<3) /* reserved for local use */
+#  define LOG_LOCAL3    (19<<3) /* reserved for local use */
+#  define LOG_LOCAL4    (20<<3) /* reserved for local use */
+#  define LOG_LOCAL5    (21<<3) /* reserved for local use */
+#  define LOG_LOCAL6    (22<<3) /* reserved for local use */
+#  define LOG_LOCAL7    (23<<3) /* reserved for local use */
 
-#  define	LOG_NFACILITIES	24	/* current number of facilities */
-#  define	LOG_FACMASK	0x03f8	/* mask to extract facility part */
+#  define LOG_NFACILITIES       24      /* current number of facilities */
+#  define LOG_FACMASK   0x03f8  /* mask to extract facility part */
                                 /* facility of pri */
-#  define	LOG_FAC(p)	(((p) & LOG_FACMASK) >> 3)
+#  define LOG_FAC(p)    (((p) & LOG_FACMASK) >> 3)
 
 /*
  * arguments to setlogmask.
  */
-#  define	LOG_MASK(pri)	(1 << (pri))		/* mask for one priority */
+#  define LOG_MASK(pri) (1 << (pri))            /* mask for one priority */
 #  define       LOG_UPTO(pri)   nBIT_MASK((pri)+1)      /* all priorities through pri */
 
 /*
@@ -874,12 +875,12 @@ int os2_do_aspawn(pTHX_ SV *really, SV **vmark, SV **vsp);
  * LOG_ODELAY no longer does anything.
  * LOG_NDELAY is the inverse of what it used to be.
  */
-#  define	LOG_PID		0x01	/* log the pid with each message */
-#  define	LOG_CONS	0x02	/* log on the console if errors in sending */
-#  define	LOG_ODELAY	0x04	/* delay open until first syslog() (default) */
-#  define	LOG_NDELAY	0x08	/* don't delay open */
-#  define	LOG_NOWAIT	0x10	/* don't wait for console forks: DEPRECATED */
-#  define	LOG_PERROR	0x20	/* log to stderr as well */
+#  define LOG_PID               0x01    /* log the pid with each message */
+#  define LOG_CONS      0x02    /* log on the console if errors in sending */
+#  define LOG_ODELAY    0x04    /* delay open until first syslog() (default) */
+#  define LOG_NDELAY    0x08    /* don't delay open */
+#  define LOG_NOWAIT    0x10    /* don't wait for console forks: DEPRECATED */
+#  define LOG_PERROR    0x20    /* log to stderr as well */
 
 #endif
 
