@@ -373,8 +373,13 @@ are in the character. */
  * One could solve for two linear equations and come up with it.) */
 #define UTF_CONTINUATION_MARK       (UTF_IS_CONTINUATION_MASK & 0xB0)
 
-/* This value is clearer in some contexts */
+/* These values are clearer in some contexts; still apply to UTF, not UTF-8 */
 #define UTF_MIN_CONTINUATION_BYTE  UTF_CONTINUATION_MARK
+#define MIN_OFFUNI_VARIANT_CP  UTF_MIN_CONTINUATION_BYTE
+
+/* This is the name to use if you are working in UTF-8, as opposed to plain
+ * 'UTF', which is I8 on EBCDIC platforms */
+#define UTF8_MIN_CONTINUATION_BYTE  I8_TO_NATIVE_UTF8(UTF_MIN_CONTINUATION_BYTE)
 
 /* Is the byte 'c' part of a multi-byte UTF8-8 encoded sequence, and not the
  * first byte thereof? */
@@ -385,8 +390,7 @@ are in the character. */
 /* Is the representation of the Unicode code point 'cp' the same regardless of
  * being encoded in UTF-8 or not? This is a fundamental property of
  * UTF-8,EBCDIC */
-#define OFFUNI_IS_INVARIANT(c)                                              \
-                        (((WIDEST_UTYPE)(c)) < UTF_MIN_CONTINUATION_BYTE)
+#define OFFUNI_IS_INVARIANT(c) (((WIDEST_UTYPE)(c)) < MIN_OFFUNI_VARIANT_CP)
 
 /*
 =for apidoc Am|bool|UVCHR_IS_INVARIANT|UV cp
@@ -931,9 +935,9 @@ case any call to string overloading updates the internal UTF-8 encoding flag.
  * complicated by the probability of having categories in different locales. */
 #define IN_UNI_8_BIT                                                    \
             ((    (      (CopHINTS_get(PL_curcop) & HINT_UNI_8_BIT))    \
-                   || (   CopHINTS_get(PL_curcop) & HINT_LOCALE_PARTIAL \
+                   || (   CopHINTS_get(PL_curcop) & HINT_LOCALE         \
                             /* -1 below is for :not_characters */       \
-                       && _is_in_locale_category(FALSE, -1)))           \
+                       && is_in_locale_category_(FALSE, -1)))           \
               && (! IN_BYTES))
 
 #define UNICODE_SURROGATE_FIRST		0xD800
@@ -1300,6 +1304,9 @@ point's representation.
  * retained solely for backwards compatibility */
 #define IS_UTF8_CHAR(p, n)      (isUTF8_CHAR(p, (p) + (n)) == n)
 
+#define MALFORMED_UTF8_DIE  TRUE
+#define MALFORMED_UTF8_WARN FALSE
+
 #endif /* PERL_UTF8_H_ */
 
 /*
